.. autobasedoc documentation master file, created by
   sphinx-quickstart on Wed Nov 15 14:10:12 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to autobasedoc's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: Install.rst

.. include:: Basic_Usage.rst

.. include:: Example.rst

.. automodule:: autobasedoc.autoplot
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: autobasedoc.autorpt
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: autobasedoc.pdfimage
    :members:
    :undoc-members:
    :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
